@@ -112,7 +112,6 @@ function(x, w, fun, filename='', na.rm=FALSE, pad=FALSE, padValue=NA, NAonly=FAL
 		}
 	}
 	if (dofun) {
-		e <- new.env()
 		if (na.rm) {
 			runfun <- function(x) as.double( fun(x, na.rm=TRUE) )
 		} else {
@@ -141,9 +140,9 @@ function(x, w, fun, filename='', na.rm=FALSE, pad=FALSE, padValue=NA, NAonly=FAL
 			
 			paddim <- as.integer(dim(v))
 			if (dofun) {
-				v <- .Call('_focal_fun', as.vector(t(v)), w, paddim, runfun, NAonly, e, NAOK=TRUE, PACKAGE='raster')
+				v <- .focal_fun(as.vector(t(v)), w, paddim, runfun, NAonly)
 			} else {
-				v <- .Call('_focal_sum', as.vector(t(v)), w, paddim, narm, NAonly, domean=domean, NAOK=TRUE, PACKAGE='raster')
+				v <- .focal_sum( as.vector(t(v)), w, paddim, narm, NAonly, domean)
 			}
 
 			v <- matrix(v, nrow=paddim[1], ncol=paddim[2], byrow=TRUE)
@@ -157,9 +156,9 @@ function(x, w, fun, filename='', na.rm=FALSE, pad=FALSE, padValue=NA, NAonly=FAL
 		} else {
 		
 			if (dofun) {
-				v <- .Call('_focal_fun', values(x), w, as.integer(dim(out)), runfun, NAonly, e, NAOK=TRUE, PACKAGE='raster')
+				v <- .focal_fun(values(x), w, as.integer(dim(out)), runfun, NAonly)
 			} else {
-				v <- .Call('_focal_sum', values(x), w, as.integer(dim(out)), narm, NAonly, domean=domean, NAOK=TRUE, PACKAGE='raster')
+				v <- .focal_sum( values(x), w, as.integer(dim(out)), narm, NAonly, domean)
 			}
 		}
 		
@@ -196,9 +195,9 @@ function(x, w, fun, filename='', na.rm=FALSE, pad=FALSE, padValue=NA, NAonly=FAL
 			paddim <- as.integer(dim(v))
 
 			if (dofun) {
-				v <- .Call('_focal_fun', as.vector(t(v)), w, paddim, runfun, NAonly, e, NAOK=TRUE, PACKAGE='raster')
+				v <- .focal_fun(as.vector(t(v)), w, paddim, runfun, NAonly)
 			} else {
-				v <- .Call('_focal_sum', as.vector(t(v)), w, paddim, narm, NAonly, domean=domean, NAOK=TRUE, PACKAGE='raster')
+				v <- .focal_sum( as.vector(t(v)), w, paddim, narm, NAonly, domean)
 			}
 			v <- matrix(v, nrow=paddim[1], ncol=paddim[2], byrow=TRUE)
 			if (padrows) {
@@ -225,9 +224,9 @@ function(x, w, fun, filename='', na.rm=FALSE, pad=FALSE, padValue=NA, NAonly=FAL
 				}
 				paddim <- as.integer(dim(v))
 				if (dofun) {
-					v <- .Call('_focal_fun', as.vector(t(v)), w, paddim, runfun, NAonly, e, NAOK=TRUE, PACKAGE='raster')
+					v <- .focal_fun(as.vector(t(v)), w, paddim, runfun, NAonly)
 				} else {
-					v <- .Call('_focal_sum', as.vector(t(v)), w, paddim, narm, NAonly, domean=domean, NAOK=TRUE, PACKAGE='raster')
+					v <- .focal_sum( as.vector(t(v)), w, paddim, narm, NAonly, domean)
 				}
 				v <- matrix(v, nrow=paddim[1], ncol=paddim[2], byrow=TRUE)
 				if (padrows) {
@@ -255,9 +254,9 @@ function(x, w, fun, filename='', na.rm=FALSE, pad=FALSE, padValue=NA, NAonly=FAL
 			paddim <- as.integer(dim(v))
 
 			if (dofun) {
-				v <- .Call('_focal_fun', as.vector(t(v)), w, paddim, runfun, NAonly, e, NAOK=TRUE, PACKAGE='raster')
+				v <- .focal_fun(as.vector(t(v)), w, paddim, runfun, NAonly)
 			} else {
-				v <- .Call('_focal_sum', as.vector(t(v)), w, paddim, narm, NAonly, domean=domean, NAOK=TRUE, PACKAGE='raster')
+				v <- .focal_sum( as.vector(t(v)), w, paddim, narm, NAonly, domean)
 			}
 			v <- matrix(v, nrow=paddim[1], ncol=paddim[2], byrow=TRUE)
 			if (padrows) {
@@ -274,18 +273,18 @@ function(x, w, fun, filename='', na.rm=FALSE, pad=FALSE, padValue=NA, NAonly=FAL
 		
 			v <- getValues(x, row=1, nrows=tr$nrows[1]+addr)
 			if (dofun) {
-				v <- .Call('_focal_fun', v, w, as.integer(c(tr$nrows[1]+addr, nc)), runfun, NAonly, e, NAOK=TRUE, PACKAGE='raster')
+				v <- .focal_fun(v, w, as.integer(c(tr$nrows[1]+addr, nc)), runfun, NAonly)
 			} else {
-				v <- .Call('_focal_sum', v, w, as.integer(c(tr$nrows[1]+addr, nc)), narm, NAonly, domean=domean, NAOK=TRUE, PACKAGE='raster')
+				v <- .focal_sum( v, w, as.integer(c(tr$nrows[1]+addr, nc)), narm, NAonly, domean)
 			}
 			out <- writeValues(out, v, 1)
 			pbStep(pb)
 			for (i in 2:(tr$n-1)) {
 				v <- getValues(x, row=tr$row[i]-addr, nrows=tr$nrows[i]+(2*addr))
 				if (dofun) {
-					v <- .Call('_focal_fun', v, w, as.integer(c(tr$nrows[i]+(2*addr), nc)), runfun, NAonly, e, NAOK=TRUE, PACKAGE='raster')
+					v <- .focal_fun(v, w, as.integer(c(tr$nrows[i]+(2*addr), nc)), runfun, NAonly)
 				} else {
-					v <- .Call('_focal_sum', v, w, as.integer(c(tr$nrows[i]+(2*addr), nc)), narm, NAonly, domean=domean, NAOK=TRUE, PACKAGE='raster')
+					v <- .focal_sum( v, w, as.integer(c(tr$nrows[i]+(2*addr), nc)), narm, NAonly, domean)
 				}
 				out <- writeValues(out, v[-nc1], tr$row[i])
 				pbStep(pb) 
@@ -293,9 +292,9 @@ function(x, w, fun, filename='', na.rm=FALSE, pad=FALSE, padValue=NA, NAonly=FAL
 			i <- tr$n
 			v <- getValues(x, row=tr$row[i]-addr, nrows=tr$nrows[i]+addr)
 			if (dofun) {
-				v <- .Call('_focal_fun', v, w, as.integer(c(tr$nrows[i]+addr, nc)), runfun, NAonly, e, NAOK=TRUE, PACKAGE='raster')
+				v <- .focal_fun(v, w, as.integer(c(tr$nrows[i]+addr, nc)), runfun, NAonly)
 			} else {
-				v <- .Call('_focal_sum', v, w, as.integer(c(tr$nrows[i]+addr, nc)), narm, NAonly, domean=domean, NAOK=TRUE, PACKAGE='raster')
+				v <- .focal_sum( v, w, as.integer(c(tr$nrows[i]+addr, nc)), narm, NAonly, domean)
 			}
 			out <- writeValues(out, v[-nc1], tr$row[i])
 			pbStep(pb) 
