@@ -3,12 +3,6 @@
 # Version 1.0
 # Licence GPL v3
 
-	
-if (!isGeneric("intersect")) {
-	setGeneric("intersect", function(x, y)
-		standardGeneric("intersect"))
-}	
-
 
 
 setMethod('intersect', signature(x='SpatialPolygons', y='SpatialPolygons'), 
@@ -315,8 +309,8 @@ function(x, y) {
 		i <- rgeos::gIntersects(y, x, byid=TRUE)
 	
 		j <- cbind(1:length(y), rep(1:length(x), each=length(y)), as.vector(t(i)))
-		j <- j[j[,3] == 1, -3]
-		j <- j[order(j[,2]), ]
+		j <- j[j[,3] == 1, -3, drop=FALSE]
+		j <- j[order(j[,2]), ,drop=FALSE]
 		x <- x[j[,2], ]
 		
 		if (.hasSlot(y, 'data')) {
@@ -331,7 +325,7 @@ function(x, y) {
 		
 	} else {
 		y <- extent(y)
-		xy <- coordinates(x)
+		xy <- coordinates(x)[,1:2,drop=FALSE]
 		i <- xy[,1] >= y@xmin & xy[,1] <= y@xmax & xy[,2] >= y@ymin & xy[,2] <= y@ymax
 		x[i, ]
 	}
