@@ -6,13 +6,17 @@
 
 .getCRSfromGridMap4 <- function(g) {
 
-	vars <- names(g)
-	vals <- as.vector(unlist(g))
+	vals <- sapply(g, function(i) i[1]) 
+	vars <- names(vals)
 	if (any(vars == "proj4")) {
 		crs=vals[vars=="proj4"] 
 		return(crs)
 	}
-	
+	if (any(vars == "epsg_code")) {
+		crs <- vals[vars=="epsg_code"] 
+		crs <- paste0("+init=", crs)
+		return(crs)
+	}
 # based on info at 
 # http://trac.osgeo.org/gdal/wiki/NetCDF_ProjectionTestingStatus
 # accessed 7 October 2012
@@ -42,7 +46,7 @@
 		vr <- vars[is.na(i)]
 		vl <- vals[is.na(i)]
 		gg <- cbind(vr, vl)
-		gg <- gg[!(gg[,1] %in% c("crs_wkt", "esri_pe_string")), ]
+		gg <- gg[!(gg[,1] %in% c("crs_wkt", "esri_pe_string")), ,drop=FALSE]
 		if (NROW(gg) > 0) {
 			mtxt <- paste(apply(gg, 1, function(x) paste(x, collapse='=')), collapse='\n')
 			warning("cannot process these parts of the CRS:\n", mtxt)
@@ -69,7 +73,7 @@
 	tab[1,3] <- prj[j,2]
 	cr <- paste(apply(tab[,2:3], 1, function(x) paste(x, collapse='=')), collapse=' ')
 	crtst <- try(CRS(cr), silent=TRUE)
-	if (class(crtst) == 'try-error') {
+	if ( inherits(crtst, "try-error")) {
 		mtxt <- paste(m, collapse='; ')
 		warning("cannot create a valid CRS\n", mtxt)
 		return(NA)
