@@ -5,13 +5,6 @@
 
 
 
-
-if ( !isGeneric("raster") ) {
-	setGeneric("raster", function(x, ...)
-		standardGeneric("raster"))
-}
-
-
 setMethod('raster', signature(x='missing'), 
 	function(nrows=180, ncols=360, xmn=-180, xmx=180, ymn=-90, ymx=90, crs, ext, resolution, vals=NULL) {
 		if (missing(ext)) {
@@ -108,31 +101,31 @@ setMethod('raster', signature(x='matrix'),
 )
 
 
-setMethod('raster', signature(x='big.matrix'), 
-	function(x, xmn=0, xmx=1, ymn=0, ymx=1, crs=NA, template=NULL) {
-		if (isTRUE(is.na(crs))) {
-			crs <- as.character(NA)
-		}	
-		if (!is.null(template)) {
-			if (inherits(template, 'Extent')) {
-				r <- raster(template, crs=crs)
-			} else {
-				r <- raster(template)
-			}
-		} else {
-			r <- raster(ncols=ncol(x), nrows=nrow(x), xmn=xmn, xmx=xmx, ymn=ymn, ymx=ymx, crs=crs)
-		}
+# setMethod('raster', signature(x='big.matrix'), 
+	# function(x, xmn=0, xmx=1, ymn=0, ymx=1, crs=NA, template=NULL) {
+		# if (isTRUE(is.na(crs))) {
+			# crs <- as.character(NA)
+		# }	
+		# if (!is.null(template)) {
+			# if (inherits(template, 'Extent')) {
+				# r <- raster(template, crs=crs)
+			# } else {
+				# r <- raster(template)
+			# }
+		# } else {
+			# r <- raster(ncols=ncol(x), nrows=nrow(x), xmn=xmn, xmx=xmx, ymn=ymn, ymx=ymx, crs=crs)
+		# }
 		
-#		r@file@driver <- 'big.matrix'
-#		if (is.filebacked(x)) {
-#			r@file@name <- bigmemory:::file.name(x)
-#		}
-		r@data@fromdisk <- TRUE
-		r@data@inmemory <- FALSE
-		attr(r@file, 'big.matrix') <- x
-		return(r)
-	}
-)
+# #		r@file@driver <- 'big.matrix'
+# #		if (is.filebacked(x)) {
+# #			r@file@name <- bigmemory:::file.name(x)
+# #		}
+		# r@data@fromdisk <- TRUE
+		# r@data@inmemory <- FALSE
+		# attr(r@file, 'big.matrix') <- x
+		# return(r)
+	# }
+# )
 
 
 
@@ -267,7 +260,7 @@ setMethod('raster', signature(x='RasterBrick'),
 				
 				# ncdf files
 				zvar <- try(methods::slot(x@data, 'zvar'), silent=TRUE)
-				if (class(zvar) != 'try-error') {
+				if (!(inherits(zvar, "try-error"))) {
 					attr(r@data, "zvar") <- zvar
 					attr(r@data, "dim3") <- x@data@dim3
 					attr(r@data, "level") <- x@data@level
@@ -489,3 +482,8 @@ setMethod('raster', signature(x='GridTopology'),
 	}
 )
 
+setMethod('raster', signature(x='SpatRaster'),
+	function(x) {
+		as(x[[1]], "Raster")
+	}
+)
