@@ -18,7 +18,9 @@ setMethod("spplot", signature(obj='Raster'),
 				warning('zlim should be a vector of two elements')
 			} 
 			if (length(zlim) >= 2) {
-				obj[obj < zlim[1] | obj > zlim[2]] <- NA
+				zlim <- sort(zlim[1:2])
+				obj[obj < zlim[1]] <- zlim[1]
+				obj[obj > zlim[2]] <- zlim[2]
 			}
 		}
 		obj <- as(obj, 'SpatialGridDataFrame')
@@ -54,3 +56,36 @@ function(x, ...) {
 }
 )
 
+
+setMethod("spplot", signature(obj='SpatRaster'), 
+	function(obj, ..., maxpixels=50000, as.table=TRUE, zlim)  {
+		obj <- sampleRegular(obj, maxpixels)
+		obj <- as(obj, "Raster")
+		if (!missing(zlim)) {
+			if (length(zlim) != 2) {
+				warning('zlim should be a vector of two elements')
+			} 
+			if (length(zlim) >= 2) {
+				obj[obj < zlim[1] | obj > zlim[2]] <- NA
+			}
+		}
+		obj <- as(obj, 'SpatialGridDataFrame')
+		spplot(obj, ..., as.table=as.table)
+	}
+)
+
+
+setMethod("spplot", signature(obj="SpatVector"), 
+	function(obj, ...)  {
+		x <- as(obj, "Spatial")
+		if (.hasSlot(x, "data")) {
+			for (i in 1:ncol(x@data)) {
+				if (is.character(x@data[,i])) {
+					x@data[,i] <- as.factor(x@data[,i])
+				}
+			}
+		}
+		spplot(x, ...)
+	}
+)
+
